@@ -21,11 +21,16 @@ describe Nori do
         xml = <<-END
           <tag>
           <![CDATA[
-            text inside cdata
+            text inside cdata &lt; test
           ]]>
           </tag>
         END
-        expect(parse(xml)["tag"].strip).to eq("text inside cdata")
+        expect(parse(xml)["tag"].strip).to eq("text inside cdata &lt; test")
+      end
+
+      it "should scrub bad characters" do
+        xml = "<tag>a\xfbc</tag>".force_encoding('UTF-8')
+        expect(parse(xml)["tag"]).to eq("a\uFFFDc")
       end
 
       it "should transform a simple tag with attributes" do
